import{N as o,O as n,P as i}from"./index-99c4f288.js";const a=n=>o("./wizard",{method:"post",body:JSON.stringify(n)}),t=o=>n(`./info?configuration=${o}`),e=n=>o(`./delete?configuration=${n}`,{method:"post"}),s=(o,n)=>i("compile",{configuration:o},void 0,n),r=o=>n(`./manifest.json?configuration=${o}`),f=(o,n)=>{let i=`./download.bin?configuration=${encodeURIComponent(o)}`;return n&&(i+="&type=firmware-factory.bin"),i};export{s as a,r as b,a as c,e as d,f as e,t as g};
